==> RSTouchscreenNG-1.3.0.zip: RSTouchscreenNG/projects/pages/src/lib/messages.component.ts <==
/* (C) 2016-2021 Hot-World GmbH & Co. KG <rlittwin@repetier.com>
 All Rights Reserved

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
 DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 It is allowed to use this code to create or use in products connecting to
 Repetier-Server or to use it for own plugins/modules with Repetier-Server.
 This includes free and commercial products.
 Usage for other products is strictly forbidden.
 */

import {Component, OnDestroy} from '@angular/core';
import {MessageState, MessagesAction, PrintersState, RepetierState} from "binding";
import {Observable, SubscriptionLike} from 'rxjs';
import {Store} from "@ngrx/store";

@Component({
    selector: 'rs-messages',
    template: `
<rs-page>
<rs-side>
    <rs-sideicon title="<?php _('Home') ?>" icon="fa fa-home" link="/"></rs-sideicon>
</rs-side><rs-side>
</rs-side>
<rs-side>
</rs-side>
<main>
    <rs-headline><i class="fa fa-envelope"></i> <?php _('Messages') ?></rs-headline>
    <div class="content-h1 " rsDrag>
        <div class="iconlist">
           <div class="button-icon sep-icon-always full leftalign button" *ngFor="let m of messages" >
                <rs-button class="secondary outline full" (hit)="messagesAction.remove(m)">
                  <i class="fa fa-envelope"></i>
                  <div class="multiline" style="white-space: pre-wrap;">
                    <h3>{{(printers$|async).printers[m.slug]?.name}}</h3>
                    <p><small>{{m.date | dateTimeShort}}</small><br>{{m.msg}}</p>
                  </div>
                </rs-button>
           </div>
        </div>
        <div *ngIf="messages.length==0" class="alert info margin">
            <?php _('No open messages') ?>
        </div>
    </div>
</main>
</rs-page>
    `
})

export class MessagesComponent implements OnDestroy {
    messages$: Observable<MessageState[]>;
    printers$: Observable<PrintersState>;
    messages: MessageState[];
    private messagesSubscription: SubscriptionLike;

    constructor(public messagesAction: MessagesAction,
                private store: Store<RepetierState>) {
      this.messages$ = store.select('messages');
      this.printers$ = store.select('printers');
        this.messagesSubscription = this.messages$.subscribe(m => {
            this.messages = m;
        });
    }

    ngOnDestroy() {
        this.messagesSubscription.unsubscribe();
    }
}

==> RSTouchscreenNG-1.4.5.zip: RSTouchscreenNG/projects/pages/src/lib/messages.component.ts <==
/* (C) 2016-2023 Hot-World GmbH & Co. KG <rlittwin@repetier.com>
 All Rights Reserved

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
 DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 It is allowed to use this code to create or use in products connecting to
 Repetier-Server or to use it for own plugins/modules with Repetier-Server.
 This includes free and commercial products.
 Usage for other products is strictly forbidden.
 */

import {Component, OnDestroy} from '@angular/core';
import {MessageState, MessagesAction, PrintersState, RepetierState} from "binding";
import {Observable, SubscriptionLike} from 'rxjs';
import {Store} from "@ngrx/store";

@Component({
  // eslint-disable-next-line @angular-eslint/component-selector
    selector: 'rs-messages',
    template: `
<rs-page>
<rs-side>
    <rs-sideicon title="<?php _('Home') ?>" icon="fa fa-home" link="/"></rs-sideicon>
</rs-side><rs-side>
</rs-side>
<rs-side>
</rs-side>
<main>
    <rs-headline><i class="fa fa-envelope"></i> <?php _('Messages') ?></rs-headline>
    <div class="content-h1 " rsDrag>
        <div class="iconlist">
           <div class="button-icon sep-icon-always full leftalign button" *ngFor="let m of messages" >
                <rs-button class="secondary outline full" (hit)="messagesAction.remove(m)">
                  <i class="fa fa-envelope"></i>
                  <div class="multiline" style="white-space: pre-wrap;">
                    <h3>{{(printers$|async).printers[m.slug]?.name}}</h3>
                    <p><small>{{m.date | dateTimeShort}}</small><br>{{m.msg}}</p>
                  </div>
                </rs-button>
           </div>
        </div>
        <div *ngIf="messages.length===0" class="alert info margin">
            <?php _('No open messages') ?>
        </div>
    </div>
</main>
</rs-page>
    `
})

export class MessagesComponent implements OnDestroy {
    messages$: Observable<MessageState[]>;
    printers$: Observable<PrintersState>;
    messages: MessageState[];
    private messagesSubscription: SubscriptionLike;

    constructor(public messagesAction: MessagesAction,
                private store: Store<RepetierState>) {
      this.messages$ = store.select('messages');
      this.printers$ = store.select('printers');
        this.messagesSubscription = this.messages$.subscribe(m => {
            this.messages = m;
        });
    }

    ngOnDestroy() {
        this.messagesSubscription.unsubscribe();
    }
}
